@@ -38,7 +38,7 @@ class Configuration:
             settings_conf = SafeConfigParser()
             settings_conf.read(
                 ospath.realpath(
-                    '{}/settings.conf'.format(ospath.dirname(__file__))))
+                    '{}/../settings.conf'.format(ospath.dirname(__file__))))
             print('Cumulus version {}'.format(
                 settings_conf.get('general', 'version')))
             sys.exit(0)
@@ -274,3 +274,6 @@ class Configuration:
         if 'pre-built-bundle' in self.config['bundles'][bundle]:
             return True
         return False
+
+
+CONFIG = Configuration()
